# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.lockbox.v1 import secret_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2
from yandex.cloud.lockbox.v1 import secret_service_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class SecretServiceStub(object):
    """A set of methods for managing secrets.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Get',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/List',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Create',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Update',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Delete',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Activate = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Activate',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/Deactivate',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListVersions = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListVersions',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.FromString,
                )
        self.AddVersion = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/AddVersion',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ScheduleVersionDestruction = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ScheduleVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.CancelVersionDestruction = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/CancelVersionDestruction',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.lockbox.v1.SecretService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class SecretServiceServicer(object):
    """A set of methods for managing secrets.
    """

    def Get(self, request, context):
        """Returns the specified secret.

        To get the list of all available secrets, make a [List] request.
        Use [PayloadService.Get] to get the payload (confidential data themselves) of the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of secrets in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a secret in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Activates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Deactivates the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVersions(self, request, context):
        """Retrieves the list of versions of the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddVersion(self, request, context):
        """Adds new version based on a previous one.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScheduleVersionDestruction(self, request, context):
        """Schedules the specified version for destruction.

        Scheduled destruction can be cancelled with the [SecretService.CancelVersionDestruction] method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelVersionDestruction(self, request, context):
        """Cancels previously scheduled version destruction, if the version hasn't been destroyed yet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the secret.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVersions,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.SerializeToString,
            ),
            'AddVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.AddVersion,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ScheduleVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.ScheduleVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'CancelVersionDestruction': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelVersionDestruction,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.lockbox.v1.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """A set of methods for managing secrets.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Get',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__pb2.Secret.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/List',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Create',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CreateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Update',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.UpdateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Delete',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Activate',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ActivateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/Deactivate',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.DeactivateSecretRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListVersions',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/AddVersion',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.AddVersionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScheduleVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ScheduleVersionDestruction',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ScheduleVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelVersionDestruction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/CancelVersionDestruction',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.CancelVersionDestructionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListOperations',
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_lockbox_dot_v1_dot_secret__service__pb2.ListSecretOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.lockbox.v1.SecretService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iot/broker/v1/broker_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.iot.broker.v1 import broker_pb2 as yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iot/broker/v1/broker_service.proto',
  package='yandex.cloud.iot.broker.v1',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;broker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/iot/broker/v1/broker_service.proto\x12\x1ayandex.cloud.iot.broker.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\'yandex/cloud/iot/broker/v1/broker.proto\"3\n\x10GetBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x12ListBrokersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x13ListBrokersResponse\x12\x33\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\".yandex.cloud.iot.broker.v1.Broker\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd0\x03\n\x13\x43reateBrokerRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12Q\n\x0c\x63\x65rtificates\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate\x12\x10\n\x08password\x18\x06 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\'\n\x0b\x43\x65rtificate\x12\x18\n\x10\x63\x65rtificate_data\x18\x01 \x01(\t\")\n\x14\x43reateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"\xef\x02\n\x13UpdateBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\x8a\xc8\x31\x04<=50\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"@\n\x1dListBrokerCertificatesRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1eListBrokerCertificatesResponse\x12\x43\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32-.yandex.cloud.iot.broker.v1.BrokerCertificate\"X\n\x1b\x41\x64\x64\x42rokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\t\"F\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"d\n\x1e\x44\x65leteBrokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1aListBrokerPasswordsRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x1bListBrokerPasswordsResponse\x12=\n\tpasswords\x18\x01 \x03(\x0b\x32*.yandex.cloud.iot.broker.v1.BrokerPassword\"W\n\x18\x41\x64\x64\x42rokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x08password\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04>=14\"C\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0bpassword_id\x18\x02 \x01(\t\"a\n\x1b\x44\x65leteBrokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x1bListBrokerOperationsRequest\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"n\n\x1cListBrokerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x80\x12\n\rBrokerService\x12\x83\x01\n\x03Get\x12,.yandex.cloud.iot.broker.v1.GetBrokerRequest\x1a\".yandex.cloud.iot.broker.v1.Broker\"*\x82\xd3\xe4\x93\x02$\x12\"/iot-broker/v1/brokers/{broker_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.iot.broker.v1.ListBrokersRequest\x1a/.yandex.cloud.iot.broker.v1.ListBrokersResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/iot-broker/v1/brokers\x12\xa1\x01\n\x06\x43reate\x12/.yandex.cloud.iot.broker.v1.CreateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"C\x82\xd3\xe4\x93\x02\x1b\"\x16/iot-broker/v1/brokers:\x01*\xb2\xd2*\x1e\n\x14\x43reateBrokerMetadata\x12\x06\x42roker\x12\xad\x01\n\x06Update\x12/.yandex.cloud.iot.broker.v1.UpdateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"O\x82\xd3\xe4\x93\x02\'2\"/iot-broker/v1/brokers/{broker_id}:\x01*\xb2\xd2*\x1e\n\x14UpdateBrokerMetadata\x12\x06\x42roker\x12\xb9\x01\n\x06\x44\x65lete\x12/.yandex.cloud.iot.broker.v1.DeleteBrokerRequest\x1a!.yandex.cloud.operation.Operation\"[\x82\xd3\xe4\x93\x02$*\"/iot-broker/v1/brokers/{broker_id}\xb2\xd2*-\n\x14\x44\x65leteBrokerMetadata\x12\x15google.protobuf.Empty\x12\xc2\x01\n\x10ListCertificates\x12\x39.yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest\x1a:.yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//iot-broker/v1/brokers/{broker_id}/certificates\x12\xdd\x01\n\x0e\x41\x64\x64\x43\x65rtificate\x12\x37.yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02\x34\"//iot-broker/v1/brokers/{broker_id}/certificates:\x01*\xb2\xd2*1\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\x42rokerCertificate\x12\xf6\x01\n\x11\x44\x65leteCertificate\x12:.yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}\xb2\xd2*8\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x15google.protobuf.Empty\x12\xb6\x01\n\rListPasswords\x12\x36.yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest\x1a\x37.yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/iot-broker/v1/brokers/{broker_id}/passwords\x12\xce\x01\n\x0b\x41\x64\x64Password\x12\x34.yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"f\x82\xd3\xe4\x93\x02\x31\",/iot-broker/v1/brokers/{broker_id}/passwords:\x01*\xb2\xd2*+\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x0e\x42rokerPassword\x12\xe9\x01\n\x0e\x44\x65letePassword\x12\x37.yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}\xb2\xd2*5\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x15google.protobuf.Empty\x12\xba\x01\n\x0eListOperations\x12\x37.yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest\x1a\x38.yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/iot-broker/v1/brokers/{broker_id}/operationsBg\n\x1eyandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;brokerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2.DESCRIPTOR,])




_GETBROKERREQUEST = _descriptor.Descriptor(
  name='GetBrokerRequest',
  full_name='yandex.cloud.iot.broker.v1.GetBrokerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.GetBrokerRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=340,
)


_LISTBROKERSREQUEST = _descriptor.Descriptor(
  name='ListBrokersRequest',
  full_name='yandex.cloud.iot.broker.v1.ListBrokersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iot.broker.v1.ListBrokersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iot.broker.v1.ListBrokersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iot.broker.v1.ListBrokersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=457,
)


_LISTBROKERSRESPONSE = _descriptor.Descriptor(
  name='ListBrokersResponse',
  full_name='yandex.cloud.iot.broker.v1.ListBrokersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokers', full_name='yandex.cloud.iot.broker.v1.ListBrokersResponse.brokers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iot.broker.v1.ListBrokersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=558,
)


_CREATEBROKERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=984,
)

_CREATEBROKERREQUEST_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_data', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate.certificate_data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1025,
)

_CREATEBROKERREQUEST = _descriptor.Descriptor(
  name='CreateBrokerRequest',
  full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificates', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.certificates', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.iot.broker.v1.CreateBrokerRequest.password', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEBROKERREQUEST_LABELSENTRY, _CREATEBROKERREQUEST_CERTIFICATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=1025,
)


_CREATEBROKERMETADATA = _descriptor.Descriptor(
  name='CreateBrokerMetadata',
  full_name='yandex.cloud.iot.broker.v1.CreateBrokerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.CreateBrokerMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1027,
  serialized_end=1068,
)


_UPDATEBROKERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=984,
)

_UPDATEBROKERREQUEST = _descriptor.Descriptor(
  name='UpdateBrokerRequest',
  full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50\362\3071\016[a-zA-Z0-9_-]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEBROKERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1438,
)


_UPDATEBROKERMETADATA = _descriptor.Descriptor(
  name='UpdateBrokerMetadata',
  full_name='yandex.cloud.iot.broker.v1.UpdateBrokerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.UpdateBrokerMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1481,
)


_DELETEBROKERREQUEST = _descriptor.Descriptor(
  name='DeleteBrokerRequest',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1537,
)


_DELETEBROKERMETADATA = _descriptor.Descriptor(
  name='DeleteBrokerMetadata',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1539,
  serialized_end=1580,
)


_LISTBROKERCERTIFICATESREQUEST = _descriptor.Descriptor(
  name='ListBrokerCertificatesRequest',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1582,
  serialized_end=1646,
)


_LISTBROKERCERTIFICATESRESPONSE = _descriptor.Descriptor(
  name='ListBrokerCertificatesResponse',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1648,
  serialized_end=1749,
)


_ADDBROKERCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='AddBrokerCertificateRequest',
  full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_data', full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest.certificate_data', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=1839,
)


_ADDBROKERCERTIFICATEMETADATA = _descriptor.Descriptor(
  name='AddBrokerCertificateMetadata',
  full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.broker.v1.AddBrokerCertificateMetadata.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1841,
  serialized_end=1911,
)


_DELETEBROKERCERTIFICATEREQUEST = _descriptor.Descriptor(
  name='DeleteBrokerCertificateRequest',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1913,
  serialized_end=2013,
)


_DELETEBROKERCERTIFICATEMETADATA = _descriptor.Descriptor(
  name='DeleteBrokerCertificateMetadata',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerCertificateMetadata.fingerprint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2015,
  serialized_end=2116,
)


_LISTBROKERPASSWORDSREQUEST = _descriptor.Descriptor(
  name='ListBrokerPasswordsRequest',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2118,
  serialized_end=2179,
)


_LISTBROKERPASSWORDSRESPONSE = _descriptor.Descriptor(
  name='ListBrokerPasswordsResponse',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='passwords', full_name='yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse.passwords', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2181,
  serialized_end=2273,
)


_ADDBROKERPASSWORDREQUEST = _descriptor.Descriptor(
  name='AddBrokerPasswordRequest',
  full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004>=14', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2362,
)


_ADDBROKERPASSWORDMETADATA = _descriptor.Descriptor(
  name='AddBrokerPasswordMetadata',
  full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_id', full_name='yandex.cloud.iot.broker.v1.AddBrokerPasswordMetadata.password_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2364,
  serialized_end=2431,
)


_DELETEBROKERPASSWORDREQUEST = _descriptor.Descriptor(
  name='DeleteBrokerPasswordRequest',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest.password_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2433,
  serialized_end=2530,
)


_DELETEBROKERPASSWORDMETADATA = _descriptor.Descriptor(
  name='DeleteBrokerPasswordMetadata',
  full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordMetadata.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password_id', full_name='yandex.cloud.iot.broker.v1.DeleteBrokerPasswordMetadata.password_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2532,
  serialized_end=2630,
)


_LISTBROKEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListBrokerOperationsRequest',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest.broker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2633,
  serialized_end=2777,
)


_LISTBROKEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListBrokerOperationsResponse',
  full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2779,
  serialized_end=2889,
)

_LISTBROKERSRESPONSE.fields_by_name['brokers'].message_type = yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2._BROKER
_CREATEBROKERREQUEST_LABELSENTRY.containing_type = _CREATEBROKERREQUEST
_CREATEBROKERREQUEST_CERTIFICATE.containing_type = _CREATEBROKERREQUEST
_CREATEBROKERREQUEST.fields_by_name['labels'].message_type = _CREATEBROKERREQUEST_LABELSENTRY
_CREATEBROKERREQUEST.fields_by_name['certificates'].message_type = _CREATEBROKERREQUEST_CERTIFICATE
_UPDATEBROKERREQUEST_LABELSENTRY.containing_type = _UPDATEBROKERREQUEST
_UPDATEBROKERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEBROKERREQUEST.fields_by_name['labels'].message_type = _UPDATEBROKERREQUEST_LABELSENTRY
_LISTBROKERCERTIFICATESRESPONSE.fields_by_name['certificates'].message_type = yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2._BROKERCERTIFICATE
_LISTBROKERPASSWORDSRESPONSE.fields_by_name['passwords'].message_type = yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2._BROKERPASSWORD
_LISTBROKEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetBrokerRequest'] = _GETBROKERREQUEST
DESCRIPTOR.message_types_by_name['ListBrokersRequest'] = _LISTBROKERSREQUEST
DESCRIPTOR.message_types_by_name['ListBrokersResponse'] = _LISTBROKERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateBrokerRequest'] = _CREATEBROKERREQUEST
DESCRIPTOR.message_types_by_name['CreateBrokerMetadata'] = _CREATEBROKERMETADATA
DESCRIPTOR.message_types_by_name['UpdateBrokerRequest'] = _UPDATEBROKERREQUEST
DESCRIPTOR.message_types_by_name['UpdateBrokerMetadata'] = _UPDATEBROKERMETADATA
DESCRIPTOR.message_types_by_name['DeleteBrokerRequest'] = _DELETEBROKERREQUEST
DESCRIPTOR.message_types_by_name['DeleteBrokerMetadata'] = _DELETEBROKERMETADATA
DESCRIPTOR.message_types_by_name['ListBrokerCertificatesRequest'] = _LISTBROKERCERTIFICATESREQUEST
DESCRIPTOR.message_types_by_name['ListBrokerCertificatesResponse'] = _LISTBROKERCERTIFICATESRESPONSE
DESCRIPTOR.message_types_by_name['AddBrokerCertificateRequest'] = _ADDBROKERCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['AddBrokerCertificateMetadata'] = _ADDBROKERCERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['DeleteBrokerCertificateRequest'] = _DELETEBROKERCERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['DeleteBrokerCertificateMetadata'] = _DELETEBROKERCERTIFICATEMETADATA
DESCRIPTOR.message_types_by_name['ListBrokerPasswordsRequest'] = _LISTBROKERPASSWORDSREQUEST
DESCRIPTOR.message_types_by_name['ListBrokerPasswordsResponse'] = _LISTBROKERPASSWORDSRESPONSE
DESCRIPTOR.message_types_by_name['AddBrokerPasswordRequest'] = _ADDBROKERPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['AddBrokerPasswordMetadata'] = _ADDBROKERPASSWORDMETADATA
DESCRIPTOR.message_types_by_name['DeleteBrokerPasswordRequest'] = _DELETEBROKERPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['DeleteBrokerPasswordMetadata'] = _DELETEBROKERPASSWORDMETADATA
DESCRIPTOR.message_types_by_name['ListBrokerOperationsRequest'] = _LISTBROKEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListBrokerOperationsResponse'] = _LISTBROKEROPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBrokerRequest = _reflection.GeneratedProtocolMessageType('GetBrokerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBROKERREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.GetBrokerRequest)
  })
_sym_db.RegisterMessage(GetBrokerRequest)

ListBrokersRequest = _reflection.GeneratedProtocolMessageType('ListBrokersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERSREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokersRequest)
  })
_sym_db.RegisterMessage(ListBrokersRequest)

ListBrokersResponse = _reflection.GeneratedProtocolMessageType('ListBrokersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERSRESPONSE,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokersResponse)
  })
_sym_db.RegisterMessage(ListBrokersResponse)

CreateBrokerRequest = _reflection.GeneratedProtocolMessageType('CreateBrokerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEBROKERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntry)
    })
  ,

  'Certificate' : _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {
    'DESCRIPTOR' : _CREATEBROKERREQUEST_CERTIFICATE,
    '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate)
    })
  ,
  'DESCRIPTOR' : _CREATEBROKERREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.CreateBrokerRequest)
  })
_sym_db.RegisterMessage(CreateBrokerRequest)
_sym_db.RegisterMessage(CreateBrokerRequest.LabelsEntry)
_sym_db.RegisterMessage(CreateBrokerRequest.Certificate)

CreateBrokerMetadata = _reflection.GeneratedProtocolMessageType('CreateBrokerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBROKERMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.CreateBrokerMetadata)
  })
_sym_db.RegisterMessage(CreateBrokerMetadata)

UpdateBrokerRequest = _reflection.GeneratedProtocolMessageType('UpdateBrokerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEBROKERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEBROKERREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.UpdateBrokerRequest)
  })
_sym_db.RegisterMessage(UpdateBrokerRequest)
_sym_db.RegisterMessage(UpdateBrokerRequest.LabelsEntry)

UpdateBrokerMetadata = _reflection.GeneratedProtocolMessageType('UpdateBrokerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBROKERMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.UpdateBrokerMetadata)
  })
_sym_db.RegisterMessage(UpdateBrokerMetadata)

DeleteBrokerRequest = _reflection.GeneratedProtocolMessageType('DeleteBrokerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerRequest)
  })
_sym_db.RegisterMessage(DeleteBrokerRequest)

DeleteBrokerMetadata = _reflection.GeneratedProtocolMessageType('DeleteBrokerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerMetadata)
  })
_sym_db.RegisterMessage(DeleteBrokerMetadata)

ListBrokerCertificatesRequest = _reflection.GeneratedProtocolMessageType('ListBrokerCertificatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERCERTIFICATESREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest)
  })
_sym_db.RegisterMessage(ListBrokerCertificatesRequest)

ListBrokerCertificatesResponse = _reflection.GeneratedProtocolMessageType('ListBrokerCertificatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERCERTIFICATESRESPONSE,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse)
  })
_sym_db.RegisterMessage(ListBrokerCertificatesResponse)

AddBrokerCertificateRequest = _reflection.GeneratedProtocolMessageType('AddBrokerCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDBROKERCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest)
  })
_sym_db.RegisterMessage(AddBrokerCertificateRequest)

AddBrokerCertificateMetadata = _reflection.GeneratedProtocolMessageType('AddBrokerCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDBROKERCERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.AddBrokerCertificateMetadata)
  })
_sym_db.RegisterMessage(AddBrokerCertificateMetadata)

DeleteBrokerCertificateRequest = _reflection.GeneratedProtocolMessageType('DeleteBrokerCertificateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERCERTIFICATEREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest)
  })
_sym_db.RegisterMessage(DeleteBrokerCertificateRequest)

DeleteBrokerCertificateMetadata = _reflection.GeneratedProtocolMessageType('DeleteBrokerCertificateMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERCERTIFICATEMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerCertificateMetadata)
  })
_sym_db.RegisterMessage(DeleteBrokerCertificateMetadata)

ListBrokerPasswordsRequest = _reflection.GeneratedProtocolMessageType('ListBrokerPasswordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERPASSWORDSREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest)
  })
_sym_db.RegisterMessage(ListBrokerPasswordsRequest)

ListBrokerPasswordsResponse = _reflection.GeneratedProtocolMessageType('ListBrokerPasswordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKERPASSWORDSRESPONSE,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse)
  })
_sym_db.RegisterMessage(ListBrokerPasswordsResponse)

AddBrokerPasswordRequest = _reflection.GeneratedProtocolMessageType('AddBrokerPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDBROKERPASSWORDREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest)
  })
_sym_db.RegisterMessage(AddBrokerPasswordRequest)

AddBrokerPasswordMetadata = _reflection.GeneratedProtocolMessageType('AddBrokerPasswordMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDBROKERPASSWORDMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.AddBrokerPasswordMetadata)
  })
_sym_db.RegisterMessage(AddBrokerPasswordMetadata)

DeleteBrokerPasswordRequest = _reflection.GeneratedProtocolMessageType('DeleteBrokerPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERPASSWORDREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest)
  })
_sym_db.RegisterMessage(DeleteBrokerPasswordRequest)

DeleteBrokerPasswordMetadata = _reflection.GeneratedProtocolMessageType('DeleteBrokerPasswordMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBROKERPASSWORDMETADATA,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.DeleteBrokerPasswordMetadata)
  })
_sym_db.RegisterMessage(DeleteBrokerPasswordMetadata)

ListBrokerOperationsRequest = _reflection.GeneratedProtocolMessageType('ListBrokerOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest)
  })
_sym_db.RegisterMessage(ListBrokerOperationsRequest)

ListBrokerOperationsResponse = _reflection.GeneratedProtocolMessageType('ListBrokerOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBROKEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.iot.broker.v1.broker_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse)
  })
_sym_db.RegisterMessage(ListBrokerOperationsResponse)


DESCRIPTOR._options = None
_GETBROKERREQUEST.fields_by_name['broker_id']._options = None
_LISTBROKERSREQUEST.fields_by_name['folder_id']._options = None
_LISTBROKERSREQUEST.fields_by_name['page_size']._options = None
_LISTBROKERSREQUEST.fields_by_name['page_token']._options = None
_CREATEBROKERREQUEST_LABELSENTRY._options = None
_CREATEBROKERREQUEST.fields_by_name['folder_id']._options = None
_CREATEBROKERREQUEST.fields_by_name['name']._options = None
_CREATEBROKERREQUEST.fields_by_name['description']._options = None
_CREATEBROKERREQUEST.fields_by_name['labels']._options = None
_UPDATEBROKERREQUEST_LABELSENTRY._options = None
_UPDATEBROKERREQUEST.fields_by_name['broker_id']._options = None
_UPDATEBROKERREQUEST.fields_by_name['name']._options = None
_UPDATEBROKERREQUEST.fields_by_name['description']._options = None
_UPDATEBROKERREQUEST.fields_by_name['labels']._options = None
_DELETEBROKERREQUEST.fields_by_name['broker_id']._options = None
_LISTBROKERCERTIFICATESREQUEST.fields_by_name['broker_id']._options = None
_ADDBROKERCERTIFICATEREQUEST.fields_by_name['broker_id']._options = None
_DELETEBROKERCERTIFICATEREQUEST.fields_by_name['broker_id']._options = None
_DELETEBROKERCERTIFICATEREQUEST.fields_by_name['fingerprint']._options = None
_DELETEBROKERCERTIFICATEMETADATA.fields_by_name['broker_id']._options = None
_DELETEBROKERCERTIFICATEMETADATA.fields_by_name['fingerprint']._options = None
_LISTBROKERPASSWORDSREQUEST.fields_by_name['broker_id']._options = None
_ADDBROKERPASSWORDREQUEST.fields_by_name['broker_id']._options = None
_ADDBROKERPASSWORDREQUEST.fields_by_name['password']._options = None
_DELETEBROKERPASSWORDREQUEST.fields_by_name['broker_id']._options = None
_DELETEBROKERPASSWORDREQUEST.fields_by_name['password_id']._options = None
_DELETEBROKERPASSWORDMETADATA.fields_by_name['broker_id']._options = None
_DELETEBROKERPASSWORDMETADATA.fields_by_name['password_id']._options = None
_LISTBROKEROPERATIONSREQUEST.fields_by_name['broker_id']._options = None
_LISTBROKEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTBROKEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTBROKEROPERATIONSREQUEST.fields_by_name['filter']._options = None

_BROKERSERVICE = _descriptor.ServiceDescriptor(
  name='BrokerService',
  full_name='yandex.cloud.iot.broker.v1.BrokerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2892,
  serialized_end=5196,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.Get',
    index=0,
    containing_service=None,
    input_type=_GETBROKERREQUEST,
    output_type=yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2._BROKER,
    serialized_options=b'\202\323\344\223\002$\022\"/iot-broker/v1/brokers/{broker_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.List',
    index=1,
    containing_service=None,
    input_type=_LISTBROKERSREQUEST,
    output_type=_LISTBROKERSRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/iot-broker/v1/brokers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEBROKERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\033\"\026/iot-broker/v1/brokers:\001*\262\322*\036\n\024CreateBrokerMetadata\022\006Broker',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEBROKERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\'2\"/iot-broker/v1/brokers/{broker_id}:\001*\262\322*\036\n\024UpdateBrokerMetadata\022\006Broker',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEBROKERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$*\"/iot-broker/v1/brokers/{broker_id}\262\322*-\n\024DeleteBrokerMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCertificates',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.ListCertificates',
    index=5,
    containing_service=None,
    input_type=_LISTBROKERCERTIFICATESREQUEST,
    output_type=_LISTBROKERCERTIFICATESRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//iot-broker/v1/brokers/{broker_id}/certificates',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddCertificate',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.AddCertificate',
    index=6,
    containing_service=None,
    input_type=_ADDBROKERCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0024\"//iot-broker/v1/brokers/{broker_id}/certificates:\001*\262\322*1\n\034AddBrokerCertificateMetadata\022\021BrokerCertificate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCertificate',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.DeleteCertificate',
    index=7,
    containing_service=None,
    input_type=_DELETEBROKERCERTIFICATEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}\262\322*8\n\037DeleteBrokerCertificateMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPasswords',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.ListPasswords',
    index=8,
    containing_service=None,
    input_type=_LISTBROKERPASSWORDSREQUEST,
    output_type=_LISTBROKERPASSWORDSRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/iot-broker/v1/brokers/{broker_id}/passwords',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddPassword',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.AddPassword',
    index=9,
    containing_service=None,
    input_type=_ADDBROKERPASSWORDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\",/iot-broker/v1/brokers/{broker_id}/passwords:\001*\262\322*+\n\031AddBrokerPasswordMetadata\022\016BrokerPassword',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePassword',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.DeletePassword',
    index=10,
    containing_service=None,
    input_type=_DELETEBROKERPASSWORDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}\262\322*5\n\034DeleteBrokerPasswordMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.iot.broker.v1.BrokerService.ListOperations',
    index=11,
    containing_service=None,
    input_type=_LISTBROKEROPERATIONSREQUEST,
    output_type=_LISTBROKEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/iot-broker/v1/brokers/{broker_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROKERSERVICE)

DESCRIPTOR.services_by_name['BrokerService'] = _BROKERSERVICE

# @@protoc_insertion_point(module_scope)
